#!/bin/sh

# Compaq W2200 Update Script
# Copyright 2001 Compaq Computer Corporation
# Version 1.01
# Release 7
# Equates to Build 28
# 6-19-01

# Script is executed by the CompaqW2200-X.X-X.i386.rpm post section > starter.sh > update

# Create UpdateError.log file ONLY if an error occurs during the execution of this script
# File is required as a flag by the GUI 

version="1.01"
release="7"
cpqcfg="20"
eqbuild="28"
updatetype="RPM Update"
err_flag="no"
datevar=(`date +%D`)

do_both()
{
    # Echo msg to standard log
    echo ${msg} >> /usr/compaq/log/LastUpdate.log
    # Echo msg to error log
    echo ${msg} >> /usr/compaq/log/UpdateError.log
    err_flag="yes"
}
do_error()
{
    # Echo msg to error log
    echo ${err_msg} >> /usr/compaq/log/UpdateError.log
    err_flag="yes"
}
do_log()
{
    # Echo msg to standard log
    echo ${msg} >> /usr/compaq/log/LastUpdate.log
}
do_preprocess()
{
    # Remove previous log symbolic link from previous update
    rm -rf /usr/compaq/log/LastUpdate.log

    # Remove any previous reference to an error log
    rm -rf /usr/compaq/log/UpdateError.log

    # Remove previous log file with same version / release
    rm -rf /usr/compaq/log/Update-${version}-${release}.log 

    # Create log file with version 
    touch /usr/compaq/log/Update-${version}-${release}.log 

    # Create symbolic link from LastUpdate.log to this versions log file for consistent GUI reference
    ln -s /usr/compaq/log/Update-${version}-${release}.log /usr/compaq/log/LastUpdate.log

    # Start Log File Here - Mark with version, date, and time
    echo "============================================================" >> /usr/compaq/log/LastUpdate.log
    echo "Compaq W2200 Update - Version " ${version}"-"${release} >> /usr/compaq/log/LastUpdate.log
    date >> /usr/compaq/log/LastUpdate.log
    echo "============================================================" >> /usr/compaq/log/LastUpdate.log

    # Log file list for /usr/compaq/update
    echo "* Files dumped to /usr/compaq/update" >> /usr/compaq/log/LastUpdate.log
    ls -l /usr/compaq/update >> /usr/compaq/log/LastUpdate.log

    # Display Start Message
    clear
    echo ""
    echo "Updating your Compaq W2200 ..........."
    echo ""
    echo "       Please Wait"
    echo ""

    # Wait 5 seconds for master rpm to close database
    sleep 5

    # Change to working directory
    if cd /usr/compaq/update ; then
        msg="Changed to /usr/compaq/update"
        do_log
    else
        msg="Cannot change directories to /usr/compaq/update"
        do_both
        msg="Cannot proceed with remaining updates"
        do_both
        exit 1
    fi
}

do_postprocess()
{
    # Remove dumped files
    rm -rf /usr/compaq/update/*
    msg="Removed update files"
    do_log

    # Display Finished Message
    clear
    echo ""
    echo "Update is complete"
    echo ""

    # Remove old version file if any
    if [ -f /_THIS_IS_VERSION* ] ; then
        rm -f /_THIS_IS_VERSION*
    fi

    # Check for errors, If errors display message and update log
    if [ "${err_flag}" = "yes" ] ; then
        echo "ERRORS WERE ENCOUNTERED DURING THE UPDATE PROCESS"
        echo ""
        echo "ERROR LOG FOLLOWS >> /usr/compaq/log/UpdateError.log"
        cat /usr/compaq/log/UpdateError.log
        echo ""
        echo "FOR MORE DETAIL REFER TO UPDATE LOG >> /usr/compaq/log/LastUpdate.log"
    fi

    # Write version file reference - complete
    touch /_THIS_IS_VERSION_${version}

    # Write update file reference - complete
    touch /_APPLIED_UPDATE_${version}-${release}

    echo ""
    echo "Press enter to continue"
}

do_historycheck()
{
    # Establish initial history.xml file if necessary  

    # Check for existence of history.xml file
    if [ -f /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml ] ; then
        # Do nothing for now
        msg=">> History data file exists"
        do_log
    else
        # Must be updating v1.00 factory image system
        # Populate with the default v1.00 history.xml
        msg=">> Creating default history data file"
        do_log
        cp -f history.xml /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore
        chmod 750 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        chown cpqcfg:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
    fi
}

do_historyupdate()
{
    # Update history.xml file with latest update record

    # Check for existence of history.xml file
        # Update with latest update information
        # Add xml record at end of file
        echo " <Upgrade>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        echo "  <Idate><![CDATA["${datevar}"]]></Idate>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        echo "  <Rdate><![CDATA[05/25/01]]></Rdate>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        if [ "${err_flag}" = "yes" ] ; then
            echo "  <Type><![CDATA[RPM Update - PARTIAL]]></Type>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        else
            echo "  <Type><![CDATA[RPM Update]]></Type>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        fi
        echo "  <Version><![CDATA["${version}"]]></Version>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        echo "  <Config><![CDATA["${cpqcfg}"]]></Config>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        echo " </Upgrade>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml

        # Remove redundant </History> tag
        cat /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml | sed '/\/History/d' >/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml.new 2>>/usr/compaq/log/LastUpdate.log
        mv -f /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml.new /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        echo "" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
        echo "</History>" >>/var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/history.xml
}

do_preprocess
do_historycheck

# ***************************************************************************
# Version specific update code STARTS HERE
# ***************************************************************************

# Start Installing

# Upgrade openssh packages ==================================================
# Upgrade all 3 pkgs in one command due to ordering and dependency problem, let rpm handle
echo "- Updating SSH packages"
msg=">> Updating openssh, openssh clients, and openssh server"
do_log
if rpm -Uvh ./openssh* 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="openssh, openssh clients, openssh server packages successful" 
    do_log
else
    msg="Failed to install openssh packages"
    do_both
fi

# Restart SSH daemon for good measure
echo "- Restarting SSH daemon"
if /etc/rc.d/init.d/sshd restart 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="ssh daemon restart successful" 
    do_log
else
    msg="ssh daemon restart failed"
    do_both
fi

# Install imap package =====================================================
# imap should not exist on the system for this update
echo "- Installing IMAP server package"
msg=">> Installing IMAP server package"
do_log
if rpm -Uvh ./imap-2000-3.i386.rpm 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="IMAP package successful" 
    do_log

    # Turn on IMAP Server in xinetd
    echo "- Enabling IMAP Server"
    if chkconfig imap on 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
        msg="imap enabled" 
        do_log
    else
        msg="imap NOT enabled - failed"
        do_both
    fi
    
    # Turn on IMAPS Server in xinetd
    echo "- Enabling IMAPS Server"
    if chkconfig imaps on 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
        msg="imaps enabled" 
        do_log
    else
        msg="imaps NOT enabled - failed"
        do_both
    fi
else
    msg="Failed to install IMAP package"
    do_both
fi


# Upgrade Proftpd package =====================================================
# ProFtpd should exist and be running already 
# Update of rpm does not change the /etc/proftpd.conf file in any way

echo "- Updating Proftpd packages"
msg=">> Updating Proftpd packages"
do_log
if rpm -Uvh ./proftpd* 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="Proftpd packages successful" 
    do_log

    # Restart Proftpd Server
    echo "- Restarting Proftpd Server"
    if /etc/rc.d/init.d/proftpd restart 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
        msg="proftpd restarted" 
        do_log
    else
        msg="proftpd NOT restarted - failed"
        do_both
    fi
else
    msg="Failed to install Proftpd packages"
    do_both
fi


# Update current CIM agents / Install Storage agent package =====================================================

echo "- Updating CIM Agent packages"
msg=">> Updating CIM Agent packages"
do_log

# Stop Current CIM Agents
# Stop NIC Agent
echo "- Stopping NIC Agent"
if /etc/rc.d/init.d/cmanic stop 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="NIC Agent stopped" 
    do_log
else
    msg="NIC Agent NOT stopped - failed"
    do_both
fi
# Stop Server Agent
echo "- Stopping Server Agent"
if /etc/rc.d/init.d/cmasvr stop 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="Server Agent stopped" 
    do_log
else
    msg="Server Agent NOT stopped - failed"
    do_both
fi
# Stop Foundation Agent
echo "- Stopping Foundation Agent"
if /etc/rc.d/init.d/cmafdtn stop 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="Foundation Agent stopped" 
    do_log
else
    msg="Foundation Agent NOT stopped - failed"
    do_both
fi


# Upgrade / Install CIM Agents
echo "- Upgrading CIM Agents"
if rpm -Uvh ./cpqhealth-2.1.0-11.Redhat7_0.i386.rpm ./cmafdtn-5.10b-1.i386.rpm ./cmanic.rpm ./cmasvr-5.10-1RC.i386.rpm ./cmastor-5.10-1.i386.rpm 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="CIM agent packages update successful" 
    do_log
else
    msg="Failed to update 1 or more CIM Agent packages"
    do_both
fi

# Detect previous RIB agent then upgrade if appropriate
if rpm -q cpqrid ; then
    # Must be scsi w/ RIB agent
    echo "- Upgrading RIB agent"
    if rpm -Uvh ./cpqrid-2.1.0-6.Redhat7_0.i386.rpm 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
	# Installed good
        msg="RIB agent package update successful" 
        do_log
    else
        msg="Failed to update RIB Agent package"
        do_both
    fi
else
    # No previous RIB board
    msg="No previous RIB agent package found - NON RIB Unit" 
    do_log
fi

# Change Health Driver Timing
echo "- Updating Health Driver Timing"
if cat /opt/compaq/server/etc/cmahealthd | sed -e 's/-p 30/-p 5/' >/opt/compaq/server/etc/cmahealthd.new 2>>/usr/compaq/log/LastUpdate.log; then
    mv -f /opt/compaq/server/etc/cmahealthd.new /opt/compaq/server/etc/cmahealthd
    # Insure correct permissions
    chown root: /opt/compaq/server/etc/cmahealthd
    chmod 775 /opt/compaq/server/etc/cmahealthd
    msg="cmahealthd update successful" 
    do_log
else
    msg="Failed to Update cmahealthd"
    do_both
fi

# Start CIM Agents
# Starting Health Agent 
echo "- Starting Health Agent"
if /etc/rc.d/init.d/cpqhealth start 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="Health Agent started" 
    do_log
else
    msg="Health Agent NOT started - failed"
    do_both
fi
# Starting Foundation Agents 
echo "- Starting Foundation Agents"
if /etc/rc.d/init.d/cmafdtn start 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="Foundation Agents started" 
    do_log
else
    msg="Foundation Agents NOT started - failed"
fi
# Starting Foundation Agents 
echo "- Starting Server Agents"
if /etc/rc.d/init.d/cmasvr start 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="Server Agents started" 
    do_log
else
    msg="Server Agents NOT started - failed"
    do_both
fi
# Starting NIC Agents 
echo "- Starting NIC Agents"
if /etc/rc.d/init.d/cmanic start 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="NIC Agents started" 
    do_log
else
    msg="NIC Agents NOT started - failed"
    do_both
fi
# Starting Storage Agents 
echo "- Starting Storage Agents"
if /etc/rc.d/init.d/cmastor start 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
    msg="Storage Agents started" 
    do_log
else
    msg="Storage Agents NOT started - failed"
    do_both
fi
echo "- Starting RIB Agents"
if rpm -q cpqrid ; then
    # RIB agent is installed
    if /etc/rc.d/init.d/cpqrid start 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
        msg="RIB Agents started" 
        do_log
    else
        msg="RIB Agents NOT started - failed"
        do_both
    fi
else
    # No previous RIB board
    msg="No attempt to start RIB agent / No previous RIB agent package found - NON RIB Unit" 
    do_log
fi



# Install ciminfo.cfg file  =====================================================
# Revised version number.. overwrite current file

echo "- Updating ciminfo.cfg file"
msg=">> Updating ciminfo.cfg file"
do_log
if cp -rf ./ciminfo.cfg /etc 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="ciminfo.cfg update successful" 
    do_log
else
    msg="Failed to update ciminfo.cfg file "
    do_both
fi

# Remove RedHat Network Daemon =====================================================

echo "- Removing RedHat Network Daemon"
msg=">> Removing RedHat Network Daemon"
do_log
if chkconfig --level 0123456 rhnsd off 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="rhnsd removal successful" 
    do_log
    if /etc/rc.d/init.d/rhnsd stop 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
        msg="rhnsd stopped" 
        do_log
    else
        msg="rhnsd NOT stopped - failed"
        do_both
    fi
else
    msg="Failed to remove rhnsd "
    do_both
fi

# Add module entries to php.ini =====================================================

echo "- Adding module entries to php.ini"
msg=">> Adding module entries to php.ini"
do_log

if echo "extension=gd.so" >> /etc/php.ini ; then
     msg="gd.so entry added to php.ini"
     do_log
     if echo "extension=mysql.so" >> /etc/php.ini ; then
          msg="mysql.so entry added to php.ini"
          do_log
          if echo "extension=pgsql.so" >> /etc/php.ini ; then
              msg="pgsql.so entry added to php.ini"
              do_log
          else
              msg="Failed to add pgsql.so entry to php.ini"
              do_both
          fi
     else
          msg="Failed to add mysql.so entry to php.ini"
          do_both
     fi
else
     msg="Failed to add gd.so entry to php.ini"
     do_both
fi


# Remove LPRng package and stop lpd =====================================================
# lpd should exist and be running already 

echo "- Removing LPRng and related packages"
msg=">> Removing LPRng and related packages"
do_log
if rpm -ev rhs-printfilters 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="rhs-printfilters removal successful" 
    do_log

    if rpm -ev LPRng 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
        msg="LPRng removal successful" 
        do_log
    else
        msg="Failed to remove LPRng package - aborted lpd halt"
        do_both
    fi
else
    msg="Failed to remove rhs-printfilters package - aborted LPRng removal"
    do_both
fi


# Update glibc packages =====================================================

echo "- Updating glibc packages"
msg=">> Updating glibc packages"
do_log
if rpm -Uvh glibc* 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    msg="glibc update successful" 
    do_log
else
    msg="Failed to update glibc packages"
    do_both
fi


# Updating sendmail.cf file =====================================================
# Restart sendmail after update

echo "- Updating sendmail.cf file and restarting"
msg=">> Updating sendmail.cf file and restarting"
do_log
# Save off original file if update fails
cp -f /etc/sendmail.cf /etc/sendmail.cf.orig

if cat /etc/sendmail.cf | sed '/Port=587/d' >/etc/sendmail.cf.new 2>>/usr/compaq/log/LastUpdate.log; then
    mv -f /etc/sendmail.cf.new /etc/sendmail.cf
    msg="sendmail.cf update successful" 
    do_log

    # Restart sendmail
    if /etc/rc.d/init.d/sendmail restart 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log ; then
        msg=" sendmail restarted" 
        do_log
    else
        msg="sendmail NOT restarted - failed"
        do_both
    fi

else
    msg="Failed to update sendmail.cf file"
    do_both
    # Replace file with original
    mv -f /etc/sendmail.cf.orig /etc/sendmail.cf
fi


# Updating logrotate.conf file =====================================================
# No restart of logrotate necessary, cron job

echo "- Updating logrotate.conf file"
msg=">> Updating logrotate.conf file"
do_log
# Save off original file if update fails
cp -f /etc/logrotate.conf /etc/logrotate.conf.orig

if cat /etc/logrotate.conf | sed '/cpqcfg/,/}/d' >/etc/logrotate.conf.new 2>>/usr/compaq/log/LastUpdate.log; then
    mv -f /etc/logrotate.conf.new /etc/logrotate.conf
    msg="logrotate.conf update successful" 
    do_log
else
    msg="Failed to update logrotate.conf file"
    do_both
    # Replace file with original
    mv -f /etc/logrotate.conf.orig /etc/logrotate.conf
fi


# Updating majordomo logrotate config file ===============================
# Add missingok directive to correct errant email to root problem

echo "- Updating majordomo log config file"
msg=">> Updating majordomo log config file"
do_log

if cat /etc/logrotate.d/majordomo | sed -e '2,20d' >/etc/logrotate.d/majordomo.new 2>>/usr/compaq/log/LastUpdate.log; then

    echo "missingok" >>/etc/logrotate.d/majordomo.new 2>>/usr/compaq/log/LastUpdate.log
    cat /etc/logrotate.d/majordomo | sed -e '1d' >>/etc/logrotate.d/majordomo.new 2>>/usr/compaq/log/LastUpdate.log
    mv -f /etc/logrotate.d/majordomo.new /etc/logrotate.d/majordomo
    msg="majordomo log config update successful" 
    do_log
else
    msg="Failed to update majordomo config file"
    do_both
fi


# Moving logrotate cron script from daily to hourly ==========================================

echo "- Updating logrotate cron script"
msg=">> Updating logrotate cron script"
do_log
# Check for possible user customization or elimination from cron.daily
if [ -f /etc/cron.daily/logrotate ] 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    # File still exists.. move it
    if rm -f /etc/cron.daily/logrotate 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then 
        # File was removed properly
        msg="logrotate removed from cron.daily successfully" 
        do_log
        # Copy rpm version to cron.hourly
        if cp /usr/compaq/update/logrotate /etc/cron.hourly 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
             # File copied successfully
             msg="logrotate copied to cron.hourly successfully" 
             do_log
             # Insure correct permissions
             chown -v root:root /etc/cron.hourly/logrotate 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
             chmod -v 755 /etc/cron.hourly/logrotate 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
             # Finished
        else
             # File was not copied properly
             msg="logrotate copy to cron.hourly failed" 
             do_both
        fi 
    else
        # File was not removed properly
        msg="logrotate removal from cron.daily failed" 
        do_both
    fi
else
    # System has been customized
    # leave it alone
    msg="logrotate does not exist in cron.daily / System customized / no action taken"
    do_log
fi


# Update Release notes and Resolved issues list ==================================================

echo "- Updating Release Notes and Resolved issues list"
msg=">> Updating Release Notes and Resolved issues list"
do_log
# Copy release.html
if cp -f /usr/compaq/update/release.html /var/cpqcfg/html 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    # Release file copied successfully
    msg="release.html updated successfully" 
    do_log
    # Insure correct permissions
    chown cpqcfg:cpqcfg /var/cpqcfg/html/release.html 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    chmod -v 770 /var/cpqcfg/html/release.html 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
else
    # File was not copied properly
    msg="release.html update failed" 
    do_both
fi
# Copy resolved.html
if cp -f /usr/compaq/update/resolved.html /var/cpqcfg/html 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    # Resolved file copied successfully
    msg="resolved.html updated successfully" 
    do_log
    # Insure correct permissions
    chown cpqcfg:cpqcfg /var/cpqcfg/html/resolved.html 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    chmod -v 770 /var/cpqcfg/html/resolved.html 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
else
    # File was not copied properly
    msg="resolved.html update failed" 
    do_both
fi


# Place Kudzu in silent mode ==================================================

echo "- Placing Kudzu in silent mode"
msg=">> Placing Kudzu in silent mode"
do_log
# Update kudzu init script
if cp -f /usr/compaq/update/kudzu /etc/rc.d/init.d 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    # Kudzu init file updated successfully
    msg="kudzu init file updated successfully" 
    do_log
    # Insure correct permissions
    chown root:root /etc/rc.d/init.d/kudzu 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    chmod -v 755 /etc/rc.d/init.d/kudzu 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
else
    # File was not updated properly
    msg="kudzu init script update failed" 
    do_both
fi


# Clear out old ipchains entries ==============================================

echo "- Clearing out old ipchains entries"
msg=">> Clearing out old ipchains entries"
do_log
if /etc/rc.d/init.d/ipchains stop; then 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    msg="ipchains stopped successfully"
    do_log
    if /etc/rc.d/init.d/ipchains save; then 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
         msg="ipchains saved successfully"
         do_log
         if /etc/rc.d/init.d/ipchains start; then 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
               msg="ipchains started successfully"
               do_log
         else
               msg="ipchains start failed"
               do_both
         fi
    else
       msg="ipchains save failed"
       do_both
    fi
else
    msg="ipchains stop failed"
    do_both

fi


# Install CompaqConfigurator 1.0-20 ========================================
cc_errflag="no"
echo "- Updating CompaqConfigurator"
msg=">> Updating CompaqConfigurator"
do_log
# Backup datastore
if cp -f /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/*.xml /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/backup 2>>/usr/compaq/log/LastUpdate.log; then
    msg="Datastore backed up"
    do_log
    # Remove template.xml
    rm -f /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/backup/template.xml
    msg="Omitting template.xml from restore"
    do_log
else
    msg="Datastore back up - Failed"
    do_both
    cc_errflag="yes"
fi

if [ "${cc_errflag}" = "yes" ] ; then
    echo "ERRORS WERE ENCOUNTERED DURING THE DATASTORE BACKUP"
    msg="ERRORS WERE ENCOUNTERED DURING THE DATASTORE BACKUP"
    do_both
    echo "CompaqConfigurator UPDATE ABORTED"
    msg="CompaqConfigurator UPDATE ABORTED"
    do_both
    msg="Failed to install CompaqConfigurator package"
    do_both
else
    # Proceed with installation of Configurator
    if rpm -Uvh ./CompaqConfigurator-1.0-20.i386.rpm 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
        msg="CompaqConfigurator package successful" 
        do_log
    else
         msg="Failed to install CompaqConfigurator package"
         do_both
    fi
fi

if cp -f /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/backup/*.xml /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore 2>>/usr/compaq/log/LastUpdate.log; then
    msg="Datastore restored"
    do_log
    # Repair ownership
    chown cpqcfg:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/*.xml
    # Copy new version of template.xml to datastore
    if cp -f /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/empty/template.xml /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
        # Insure correct permissions
        chown cpqcfg:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/template.xml 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
        chmod -v 770 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/template.xml 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
        msg="Copied new version of template.xml to datastore"
        do_log
    else
        msg="Cannot copy template.xml to datastore"
        do_both
    fi
else
    msg="Datastore restore - Failed"
    do_both
fi

# Install and Execute fix for upgrade datastore ======================================================

echo "- Placing datastore converter checkDatastore.pl"
msg=">> Placing datastore converter checkDatastore.pl"
do_log

if cp -f /usr/compaq/update/checkDatastore.pl /var/cpqcfg/cgi-bin/CompaqConfigurator/system 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    # checkDatastore.pl file installed successfully
    msg="checkDatastore.pl file installed successfully" 
    do_log
    # Insure correct permissions
    chown cpqcfg:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/checkDatastore.pl 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    chmod -v 770 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/checkDatastore.pl 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    # Execute to convert database
    if /var/cpqcfg/cgi-bin/CompaqConfigurator/system/checkDatastore.pl 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
         msg="Datastore conversion successfull" 
         do_log
    else
         msg="Datastore conversion failed" 
         do_log
    fi
else
    # File was not copied properly
    msg="checkDatastore.pl file install failed" 
    do_both
fi

# Re-establish IPCHAINS entries by resetting network =================================================

echo "- Re-establish IPCHAINS rules "
msg=">> Re-establishing IPCHAINS rules"
do_log
if /var/cpqcfg/cgi-bin/CompaqConfigurator/system/custom/custom update_services; then
     msg="Re-establish IPCHAINS rules successfull" 
     do_log
else
     msg="Re-establish IPCHAINS rules FAILED" 
     do_both
fi

# Provide redirect for history.cpq to release.html====================================================

echo "- Placing custom history.cpq"
msg=">> Placing custom history.cpq"
do_log
# Update history.cpq      
if cp -f /usr/compaq/update/history.cpq /var/cpqcfg/cgi-bin/CompaqConfigurator/systemAdmin 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    # history.cpq file updated successfully
    msg="history.cpq file updated successfully" 
    do_log
    # Insure correct permissions
    chown cpqcfg:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/systemAdmin/history.cpq 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    chmod -v 770 /var/cpqcfg/cgi-bin/CompaqConfigurator/systemAdmin/history.cpq 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
else
    # File was not updated properly
    msg="history.cpq file update failed" 
    do_both
fi

# Update Help system files ==========================================================================

echo "- Updating Help system files"
msg=">> Updating Help system files"
do_log
# Remove current web help files
if rm -rf /var/cpqcfg/html/webhelp 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log; then
    # Removal of old help files successful
    msg="Removal of old help files successful"
    do_log
    # Un-tar new help files
    cd /var/cpqcfg/html
    if tar -xvf /usr/compaq/update/webhelp.tar 2>>/usr/compaq/log/LastUpdate.log; then
        # Untar of new help files successful  
        msg="Untar of new help files successful" 
        do_log
        # Set proper ownership to webhelp files
        chown -R cpqcfg:cpqcfg /var/cpqcfg/html/webhelp 1>>/usr/compaq/log/LastUpdate.log 2>>/usr/compaq/log/LastUpdate.log
    else
        msg="Untar of new help files - Failed"
        do_both
    fi
else
    msg="Removal of old help files - Failed"
    do_both
fi

# ***************************************************************************
# Version specific update code ENDS HERE
# ***************************************************************************
do_historyupdate
do_postprocess
