#!/bin/bash
#
#  Program:      setup.sh
#
#  Description:  This program does post installation configuration to allow
#    the configurator to run properly.
#
#  History:
#
#

echo "Starting Compaq Configurator setup script..."

#echo "  - Stopping Compaq Configurator..."
#/etc/rc.d/init.d/cpqcfg stop

echo "  - Stopping Apache"
/etc/rc.d/init.d/httpd stop

# First we add the cpqcfg user
echo "  - Adding \"cpqcfg\" user..."
/usr/sbin/adduser -u 300 -d /var/cpqcfg cpqcfg
echo "  - Adding \"site_admins\" group..."
/usr/sbin/groupadd site_admins

# Setup temporary restore directory
if [ -a /var/tmp ]; then
    echo "  - Temporary restore directory already exists...(This must be an upgrade)"
else 
    echo "  - Building temporary restore directory"
    rm -rf /var/tmp
    mkdir /home/tmp
    chown root:root /home/tmp
    chmod ugo+rw /home/tmp
    ln -s /home/tmp /var/tmp
fi

# Install cpqcfg PAM config file
if [ -a /etc/cpqcfgusers ]; then
    echo "  - Skipping CPQCFG PAM module installation...(This must be an upgrade)"
else
    echo "  - Installing CPQCFG PAM module..."
    cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/cpqcfg.pam /etc/pam.d/cpqcfg
    cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/cpqcfgusers /etc/cpqcfgusers
    chown root:root /etc/pam.d/cpqcfg
    chmod go-rwx /etc/pam.d/cpqcfg
    chmod go+r /etc/pam.d/cpqcfg
fi

# Make dummy SSL CRT file
if [ -a /etc/httpd.conf/ssl.crt/server.crt ]; then
    echo "  - Skipping the SSL certificate creation...(This must be an upgrade)"
else
    echo "  - Installing dummy SSL certificate..."
    touch /etc/httpd/conf/ssl.crt/server.crt
fi

echo "  - Installing PAM modifications to telnet, ftp, ssh, imap, and pop3"
touch /etc/ftpusers
touch /etc/telnetusers
touch /etc/sshusers
touch /etc/pop3users
touch /etc/imapusers
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/sshd.pam /etc/pam.d/sshd
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/ftp.pam /etc/pam.d/ftp
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/rlogin.pam /etc/pam.d/rlogin
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/login.pam /etc/pam.d/login
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/pop3.pam /etc/pam.d/pop3
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/imap.pam /etc/pam.d/imap
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/imapusers /etc/imapusers
chmod ugo+r /etc/imapusers
chown root:root /etc/imapusers
chown root:root /etc/pam.d/*
chmod go-wx /etc/pam.d/*
chmod g-r /etc/pam.d/sshd

# Make the Virtual Sites directory
if [ -a /home/VirtualSites ]; then
    echo "  - /home/VirtualSites already exists...(This must be an upgrade)"
else
    echo "  - Building Virtual Sites directory (/home/VirtualSites)..."
    mkdir /home/VirtualSites
    chown cpqcfg:cpqcfg /home/VirtualSites
fi

# Add the include line to the main httpd.conf file
echo "  - Including vhost.conf in main httpd.conf file..."
touch /etc/httpd/conf/vhosts.conf
EXISTS=`grep "Include /etc/httpd/conf/vhosts.conf" /etc/httpd/conf/httpd.conf`

if [ "$EXISTS" != "" ]; then
    echo "    * Virtual Hosts file already included"
else
    echo "    * Adding Virtual Hosts file inclusion directive"
    echo "Include /etc/httpd/conf/vhosts.conf" >> /etc/httpd/conf/httpd.conf
fi

# Set default Administrator password
if [ -a /var/cpqcfg/cgi-bin/CompaqConfigurator/systemAdmin/.htpasswd ]; then
    echo "  - Skipping administrator password reset...(This must be an upgrade)"
else
    echo "  - Setting default administrator password...(administrator/administrator)"
    htpasswd -bc /var/cpqcfg/cgi-bin/CompaqConfigurator/systemAdmin/.htpasswd administrator administrator
fi

# Set general permissions on all files
echo "  - Settings permissions..."
chown -R cpqcfg:cpqcfg /var/cpqcfg/*
chmod -R 770 /var/cpqcfg/*

# Set SUID on custom components
echo "  - Setting SUID on select programs..."
chown root:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/custom/custom
chmod 4550 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/custom/custom
chown root:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/bin/*
chmod 4550 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/bin/*
chown root:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/reports/alerts.cpq
chmod 4550 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/reports/alerts.cpq
chown root:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/reports/webalizer.cpq
chmod 4550 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/reports/webalizer.cpq

# Wipe out webalizer information
if [ -a /var/cpqcfg/html/webalizer/index.html ]; then
    echo "  - Webalizer already installed...(This must be an upgrade)"
else
    echo "  - Scheduling and initializing webalizer..."
    mkdir /var/cpqcfg/html/webalizer
    rm /var/cpqcfg/html/webalizer/*
    echo "<HTML><HEAD></HEAD><BODY bgcolor=white><CENTER><H3>Web server statistics not collected yet.</H3><P>The web server statistics will be collected once each hour.  Once the statistics have been collected, you may view the data at this location.</CENTER></BODY></HTML>" > /var/cpqcfg/html/webalizer/index.html
    chown cpqcfg:cpqcfg /var/cpqcfg/html/webalizer/index.html
fi

# Make sure that genericsdomain exists
if [ -a /etc/mail/genericsdomain ]; then
    echo "  - Sendmail genericsdomain file found...(This must be an upgrade)"
else
    echo "  - Making genericsdomain file"
    touch /etc/mail/genericsdomain
fi

# Start routine webalizer reports (LEAVE THE NEW LINES IN!!!)
echo "  - Scheduling and initializing reports and alerts..."
echo "MAILTO=\"\"
30 * * * * /var/cpqcfg/cgi-bin/CompaqConfigurator/system/reports/webalizer.cpq
0-59/15 * * * * /var/cpqcfg/cgi-bin/CompaqConfigurator/system/reports/alerts.cpq
" | /usr/bin/crontab -u cpqcfg -

# Install the startup script
if [ -a /etc/rc.d/init.d/cpqcfg ]; then
    echo "  - cpqcfg already in init.d...(This must be an upgrade)"
else
    echo "  - Tying configurator into normal run-level..."
    cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/cpqcfg /etc/rc.d/init.d/cpqcfg
    chown root:root /etc/rc.d/init.d/cpqcfg
    chmod 770 /etc/rc.d/init.d/cpqcfg
    # Hook into the normal run-level
    ln -s /etc/rc.d/init.d/cpqcfg /etc/rc.d/rc3.d/S85cpqcfg
    ln -s /etc/rc.d/init.d/cpqcfg /etc/rc.d/rc3.d/K85cpqcfg
fi

# Erase the datastore
if [ -a /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/users.xml ]; then
    echo "  - Datastore already installed...(This must be an upgrade)"    
else
    echo "  - Installing new datastore..."
    cp /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/empty/*.xml /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore
    chown cpqcfg:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/*
    chmod 770 /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/*
    mkdir /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/backup
    chown cpqcfg:cpqcfg /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/backup
    chmod o-rwx /var/cpqcfg/cgi-bin/CompaqConfigurator/system/datastore/backup
fi

# Run the initialization program
echo "  - Synching datastore with current configuration..."
/var/cpqcfg/cgi-bin/CompaqConfigurator/setup/initialize.cpq

# Update the package list
#echo "  - Updating current package list for software configuration..."
#rpmquery -qa > /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/package.lst

# Updating httpd.conf
EXISTS=`grep "<IfModule mod_speling.c>" /etc/httpd/conf/httpd.conf`

if [ "$EXISTS" != "" ]; then
    echo "  - Modular httpd.conf seems to already exist. Not replacing '/etc/httpd/conf/httpd.conf'...(This must be an upgrade)"
else
    echo "  - Replacing httpd.conf with modular config file..."
    cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/httpd.conf /etc/httpd/conf/httpd.conf
fi

# Clearing cpqcfg log files
echo "  - Clearing cpqcfg log files"
rm /var/cpqcfg/httpd/log/*

# Setup log rotation
echo "  - Setting up cpqcfg log rotation"
EXISTS=`grep "/var/cpqcfg/httpd/log/*" /etc/logrotate.conf`
if [ "$EXISTS" != "" ]; then
    echo "    * CPQCFG log rotate entry already included...(This must be an upgrade)"
else
    cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/logrotate.conf /etc/logrotate.conf
fi

# Setup log rotation for cpqcfg
echo "    * Adding CPQCFG log rotation config file (/etc/logrotate.d)..."
cp /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/cpqcfg.logrotate /etc/logrotate.d/cpqcfg

# Front Page setup
echo "  - Upgrading front page config files...(If necessary)"
/bin/sh -c /var/cpqcfg/cgi-bin/CompaqConfigurator/setup/upgradefp.pl 2> /dev/null &
if [ -a /etc/httpd/conf/fphttpd.conf ]; then
    echo "  - Front Page seems to already be installed...(This must be an upgrade)"
else
    echo "  - Building fphttpd.conf and mod_frontpage.so for Front Page requirements..."
    rm /etc/httpd/conf/fphttpd.conf
    touch /etc/httpd/conf/fphttpd.conf
    chown cpqcfg:cpqcfg /etc/httpd/conf/fphttpd.conf
    touch /usr/lib/apache/mod_frontpage.so
fi

if [ -a /usr/local/frontpage/version4.0/bin/fpsrvadm_suid.exe ]; then
    echo "  - Front Page Server Admin tool seems to already be installed...(This must be an upgrade)"
else
    echo "  - Installing Front Page Server Admin tool..."
    cp /usr/local/frontpage/version4.0/bin/fpsrvadm.exe /usr/local/frontpage/version4.0/bin/fpsrvadm_suid.exe
    chown root:cpqcfg /usr/local/frontpage/version4.0/bin/fpsrvadm_suid.exe
    chmod 550 /usr/local/frontpage/version4.0/bin/fpsrvadm_suid.exe
    chmod u+s /usr/local/frontpage/version4.0/bin/fpsrvadm_suid.exe
fi

# Clean-up the directories
echo "  - Cleaning up installation directories"
#rm -rf /var/cpqcfg/cgi-bin/CompaqConfigurator/setup
rm /var/cpqcfg/cgi-bin/CompaqConfigurator/util/displayErrors.cpq 2> /dev/null
rm /var/cpqcfg/cgi-bin/CompaqConfigurator/util/displayMessages.cpq 2> /dev/null
rm /var/cpqcfg/cgi-bin/CompaqConfigurator/util/programInfo.cpq 2> /dev/null
rm /var/cpqcfg/cgi-bin/CompaqConfigurator/util/showCode.cpq 2> /dev/null

# Dump log files
echo "  - Dumping log files"
mkdir /var/cpqcfg/httpd/log
mkdir /var/cpqcfg/httpd/run
touch /var/cpqcfg/httpd/log/error_log
touch /var/cpqcfg/httpd/log/access_log
chown cpqcfg:cpqcfg /var/cpqcfg/httpd/log/*

# Startup the main web server
echo "  - Starting Apache..."
/etc/rc.d/init.d/httpd start

# Startup the configurator
echo "  - Starting Compaq Configurator..."
/etc/rc.d/init.d/cpqcfg start

# END OF SCRIPT
echo "** Finished! **"
