package custom;
#
#  Package:      custom.pm
#
#  Description:  The OS specific routines for changing the system.
#    The routines in this package assume the XML has already been
#    changed.  They attempt to bring integrity back to the system
#    by adding/removing users, changing network settings, restarting
#    services, writing out to config files, etc.
#
#  History:
#
use strict;

use CGI;
use XML::DOM;
use XML::QL;

use config;
use general;

# A sub-routine to change a network interface
sub updateInterface {

    my $interface = shift || return(0);

    if ($interface eq "eth0") {
	return(0);
    }

    my %system = config::system();
    my $configFile = "/etc/sysconfig/network-scripts/ifcfg-" . $interface;

    # Build the query
    my $query = 'WHERE
         <Interface if="' . $interface . '">
           <IP>$ip</IP>
           <DHCP>$dhcp</DHCP>
           <NetMask>$netmask</NetMask>
           <Network>$network</Network>
           <Broadcast>$bcast</Broadcast>
           <DefaultGateway>$gateway</DefaultGateway>
         </Interface>
      IN "file:' . $system{'root'} . '/system/profiles/network.xml"
      CONSTRUCT $ip</TD><TD>$dhcp</TD><TD>$netmask</TD><TD>$network</TD><TD>$bcast</TD><TD>$gateway';

    my $result = XML::QL->query($query);

    # Check to see if we've found the interface
    if ($result eq "") {
	print "No interface configuration information found for $interface!";
	return(0);
    }
    else {

	my @values = split(/<\/TD><TD>/, $result);

	my $ip = $values[0] || "";
	my $dhcp = $values[1] || "";
	my $netmask = $values[2] || "";
	my $network = $values[3] || "";
	my $bcast = $values[4] || "";
	my $gateway = $values[5] || "";

	# Add a notice that the file was modified by the Compaq Configurator
	my $message = "# File Modified by Compaq Configurator";
	my $date = `date`;

	my @lines = ();
	$lines[0] = "$message - $date";
	$lines[1] = "DEVICE=$interface";

	if ($dhcp eq "Yes") {
	    $lines[2] = "BOOTPROTO=dhcp";
	}
	else {
	    $lines[2] = "IPADDR=$ip";
	    $lines[3] = "NETMASK=$netmask";
	    $lines[4] = "NETWORK=$network";
	    $lines[5] = "BROADCAST=$bcast";
	    $lines[6] = "GATEWAY=$gateway";
	}

	push(@lines, "ONBOOT=yes");

	# Write the file back out
	if (open(FILE,">$configFile")) {

	    foreach my $line (@lines) {
		print FILE "$line\n";
	    }
	
	    close(FILE);
	
	}

	# Restart that interface
	my $command = "/etc/sysconfig/network-scripts/ifup $interface";
	print "Command = $command\n";
	`$command`;

	# Do post configuration updates to the XML
	my $ifconfig = `/sbin/ifconfig $interface`;
	my $route = `/sbin/route -n`;

	$ifconfig =~ /inet addr:([\d\.]*)/;
	my $ip = $1;
	$ifconfig =~ /Mask:([\d\.]*)/;
	my $netmask = $1;
	$ifconfig =~ /Bcast:([\d\.]*)/;
	my $bcast = $1;
	$ifconfig =~ /HWaddr:([\d\:]*)/;
	my $macaddr = $1;

	$route =~ /0\.0\.0\.0.*$interface/;
	my $gateway = $1;

	# Update the XML
	my $parser = new XML::DOM::Parser;
	my $doc = $parser->parsefile("$system{'root'}/system/profiles/network.xml");

	my $interfaces = $doc->getElementsByTagName("Interface");
	my $numOfInterfaces = $interfaces->getLength;

	my $interfaceNode = "";

	for (my $i=0; $i<$numOfInterfaces; $i++) {
	    
	    my $if = eval { $interfaces->item($i)->getAttribute("if"); } || "";

	    # Did we find the right node?
	    if ($if eq $interface) {
		$interfaceNode = $interfaces->item($i);
	    }
	    
	}
	
	if ($interfaceNode eq "") {
	    print "<H1><FONT color=red>Unknown interface: $interface</FONT></H1>";
	}
	else {

 	    general::textNodeUpdate($interfaceNode->getElementsByTagName("MACAddress")->item(0), "$ip");
	    general::textNodeUpdate($interfaceNode->getElementsByTagName("IP")->item(0), "$ip");
	    general::textNodeUpdate($interfaceNode->getElementsByTagName("NetMask")->item(0), "$netmask");
	    general::textNodeUpdate($interfaceNode->getElementsByTagName("Broadcast")->item(0), "$bcast");
	    general::textNodeUpdate($interfaceNode->getElementsByTagName("DefaultGateway")->item(0), "$gateway");
	    
	    # Write out the file
	    $doc->printToFile("$system{'root'}/system/profiles/network.xml");
	    
	    $doc->dispose();
	}
	
    }

    return(1);

}

# A sub-routine to shut the system down
sub shutdown {

    my $postAction = shift || "";
    my $when = shift || "";

    my $command = "";

    # Determine the type of shutdown
    if ($postAction eq "halt") {
	$command = "/sbin/shutdown -h $when";
    }
    else {
	$command = "/sbin/shutdown -h $when";
    }

    # Do the shutdown
    print "$command\n";
    `$command`;

    return (1);

}

1;

