package custom;
#
#  Package:      custom.pm
#
#  Description:  The OS specific routines for changing the system.
#    The routines in this package assume the XML has already been
#    changed.  They attempt to bring integrity back to the system
#    by adding/removing users, changing network settings, restarting
#    services, writing out to config files, etc.
#
#  History:
#
use strict;

use CGI;
use XML::DOM;
use XML::QL;

use config;

sub updateInterface {

    my $interface = shift || "";

    my %system = config::system();
    my $configFile = "/tmp/rc.config";
    my @lines = ();
    my $netdev = "NOTHING";

    # Build the query
    my $query = 'WHERE
         <Interface if="' . $interface . '">
           <IP>$ip</IP>
           <DHCP>$dhcp</DHCP>
           <NetMask>$netmask</NetMask>
           <DefaultGateway>$gateway</DefaultGateway>
         </Interface>
      IN "file:' . $system{'setuproot'} . '/network.xml"
      CONSTRUCT $ip<TD></TD>$dhcp<TD></TD>$gateway<TD></TD>$netmask';

    my $result = XML::QL->query($query);

    # Check to see if we've found the interface
    if ($result eq "") {

	print "No interface configuration information found for $interface!";

	return(0);
    }
    else {

	my @values = split(/<TD><\/TD>/, $result);

	my $ip = $values[0] || "";
	my $dhcp = $values[1] || "";
	my $gateway = $values[2] || "";
	my $netmask = $values[3] || "";

	# Read each line of the config file
	open(FILE, "<$configFile");
	@lines = <FILE>;
	close(FILE);

	# First we run through the lines looking for the correct "NETDEV_?"
	foreach my $line (@lines) {

	    if ($line =~ /#/) {
		next;
	    }
	    elsif ($line =~ /NETDEV_\d="$interface"/) {

		$netdev = substr($line,7,1);
	    }

	}

	# Run through the lines looking for/changing IP setup
	my $numOfLines = scalar(@lines);
	for (my $i=0; $i<$numOfLines; $i++) {

	    if ($lines[$i] =~ /#/) {
		next;
	    }
	    elsif ($lines[$i] =~ /IPADDR_$netdev/) {
		$lines[$i] = "IPADDR_" . $netdev . "=\"$ip\"\n";
	    }
	    elsif ($lines[$i] =~ /IFCONFIG_$netdev/) {

		if ($dhcp eq "Yes") {
		    $lines[$i] = "IFCONFIG_" . $netdev . "=\"dhcpclient\"\n";
		}
		else {
		    $lines[$i] = "IFCONFIG_" . $netdev . "=\"$ip broadcast ??? netmask $netmask\"\n";
		}
	    }

	}

    }

    # Write the file back out
    if (open(FILE,">$configFile")) {

	print FILE "# File Modified by Compaq Configurator NETDEV = $netdev INTERFACE = '$interface'\n";
	
	foreach my $line (@lines) {
	    
	    print FILE "$line";
	
	}

	close(FILE);

    }

    # Restart the network
    `/etc/rc.d/init.d/network restart&`;

    return(1);

}

1;

